powered by
Performs source of variation test and build PCA and t-SNE plots to visualize important information.
lilikoi.explr(data, demo.data, pca = FALSE, tsne = FALSE)
Source of variation test results and PCA and t-SNE plot
is a input data frame for analysis with sample ids as row names and metabolite names or pathway names as column names.
is a demographic data frame with sample ids as row names, sample groups and demographic variable names as column names.
if TRUE, PCA plot will be out.
if TRUE, T-SNE plot will be out.
# \donttest{ # lilikoi.explr(data, demo.data, pca=TRUE, tsne=FALSE) # }
Run the code above in your browser using DataLab