Learn R Programming

lilikoi (version 2.1.1)

lilikoi.meta_path: Metabolite-pathway regression

Description

Performs single variate linear regression between selected pathways and each of their metabolites. Output the network plot between pathways and metabolties.

Usage

lilikoi.meta_path(
  PDSmatrix,
  selected_Pathways_Weka,
  Metabolite_pathway_table,
  pathway = "Pyruvate Metabolism"
)

Value

A bipartite graph of the relationships between pathways and their corresponding metabolites.

Arguments

PDSmatrix

Pathway deregulation score matrix

selected_Pathways_Weka

Selected top pathways from the featureSelection function

Metabolite_pathway_table

Metabolites mapping table

pathway

interested pathway name