Learn R Programming

lilikoi (version 2.1.1)

lilikoi.preproc_norm: A Normalization function.

Description

This function is used to preprocess data via normalization. It provides three normalization methods: standard normalization, quantile normalization and median fold normalization. The median fold normalization is adapted from http://www.metabolomics-forum.com/index.php?topic=281.0.

Usage

lilikoi.preproc_norm(
  inputdata = Metadata,
  method = c("standard", "quantile", "median")
)

Value

A normalized dataset with samples in the rows, metabolites in the columns.

Arguments

inputdata

An expression data frame with samples in the rows, metabolites in the columns

method

The method to be used to process data, including standard normalization (standard), quantile normalization (quantile) and median fold normalization (median).

Examples

Run this code
# \donttest{
dt <- lilikoi.Loaddata(file=system.file("extdata",
 "plasma_breast_cancer.csv", package = "lilikoi"))
Metadata <- dt$Metadata
dataSet <- dt$dataSet
lilikoi.preproc_norm(inputdata=Metadata, method="standard")
# }

Run the code above in your browser using DataLab