Performs single variate linear regression between selected pathways and each of their metabolites. Output the network plot between pathways and metabolties.
lilikoi.meta_path(
PDSmatrix,
selected_Pathways_Weka,
Metabolite_pathway_table,
pathway = "Pyruvate Metabolism"
)A bipartite graph of the relationships between pathways and their corresponding metabolites.
Pathway deregulation score matrix
Selected top pathways from the featureSelection function
Metabolites mapping table
interested pathway name